@@ -17,8 +17,7 @@ from chaoslib.notification import notify, DiscoverFlowEvent, InitFlowEvent, \
     RunFlowEvent, ValidateFlowEvent
 from chaoslib.settings import load_settings, locate_settings_entry, \
     save_settings, CHAOSTOOLKIT_CONFIG_PATH
-from chaoslib.types import Activity, Discovery, Experiment, Journal, \
-    Schedule, Strategy
+from chaoslib.types import Activity, Discovery, Experiment, Journal, Schedule
 import click
 from click_plugins import with_plugins
 try:
@@ -29,7 +28,8 @@ from logzero import logger
 import yaml
 
 from chaostoolkit import __version__, encoder
-from chaostoolkit.check import check_newer_version
+from chaostoolkit.check import check_newer_version, \
+    check_hypothesis_strategy_spelling
 from chaostoolkit.logging import configure_logger
 
 
@@ -88,7 +88,7 @@ def cli(ctx: click.Context, verbose: bool = False,
 def validate_vars(ctx: click.Context, param: click.Option,
                   value: List[str]) -> Dict[str, Any]:
     """
-    Process all `--var key=value` and return a dictionnary of them with the
+    Process all `--var key=value` and return a dictionary of them with the
     value converted to the appropriate type.
     """
     try:
@@ -126,15 +126,15 @@ def validate_vars(ctx: click.Context, param: click.Option,
 @click.option('--hypothesis-strategy', default="default",
               type=click.Choice([
                   "default", "before-method-only", "after-method-only",
-                  "during-method-only", "continously"
+                  "during-method-only", "continuously", "continously"
               ], case_sensitive=True),
               help='Strategy to execute the hypothesis during the run.')
 @click.option('--hypothesis-frequency', default=1.0, type=float,
               help='Pace at which running the hypothesis. '
                    'Only applies when strategy is either: '
-                   'during-method-only or continously')
+                   'during-method-only or continuously')
 @click.option('--fail-fast', is_flag=True, default=False,
-              help='When running in the during-method-onlyt or continous '
+              help='When running in the during-method-only or continuous '
                    'strategies, indicate the hypothesis can fail the '
                    'experiment as soon as it deviates once. Otherwise, keeps '
                    'running until the end of the experiment.')
@@ -179,9 +179,10 @@ def run(ctx: click.Context, source: str, journal_path: str = "./journal.json",
     settings.setdefault(
         "runtime", {}).setdefault("rollbacks", {}).setdefault(
             "strategy", rollback_strategy)
-    hypothesis_strategy = Strategy.from_string(hypothesis_strategy)
+    hypothesis_strategy = \
+        check_hypothesis_strategy_spelling(hypothesis_strategy)
     schedule = Schedule(
-        continous_hypothesis_frequency=hypothesis_frequency,
+        continuous_hypothesis_frequency=hypothesis_frequency,
         fail_fast=fail_fast)
 
     journal = run_experiment(
@@ -490,7 +491,6 @@ def init(ctx: click.Context, discovery_path: str = "./discovery.json", #noqa: C9
         click.echo("No discovery was found, let's create an empty experiment")
 
     base_experiment = {
-        "version": "1.0.0",
         "title": "",
         "description": "N/A",
         "tags": []
@@ -659,7 +659,7 @@ def add_activities(activities: List[Activity], pool: List[Activity],  #noqa: C90
         click.secho(
             "\nA steady-state probe requires a tolerance value, "
             "within which\n"
-            "your system is in a reognised `normal` state.\n",
+            "your system is in a recognised `normal` state.\n",
             fg="blue")
         tolerance_value = click.prompt(
             s("What is the tolerance for this probe?", fg='green'))
